==> mule-message-metadata-model-1.0.0-sources.jar: org/mule/metadata/message/api/MuleEventMetadataTypeBuilder.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.metadata.message.api;


import org.mule.metadata.api.annotation.TypeAnnotation;
import org.mule.metadata.api.builder.AbstractBuilder;
import org.mule.metadata.api.builder.BaseTypeBuilder;
import org.mule.metadata.api.builder.ObjectFieldTypeBuilder;
import org.mule.metadata.api.builder.ObjectTypeBuilder;
import org.mule.metadata.api.builder.WithAnnotation;
import org.mule.metadata.api.model.MetadataFormat;
import org.mule.metadata.api.model.MetadataType;
import org.mule.metadata.api.model.ObjectFieldType;
import org.mule.metadata.api.model.ObjectType;

import java.util.Collection;
import java.util.Optional;

/**
 * Builder for the {@link MuleEventMetadataType}
 */
public class MuleEventMetadataTypeBuilder extends AbstractBuilder<MuleEventMetadataType>
    implements WithAnnotation<MuleEventMetadataTypeBuilder> {

  private MessageMetadataType messageMetadataType;
  private MessageMetadataTypeBuilder messageTypeBuilder;
  private ObjectTypeBuilder variables;

  public MuleEventMetadataTypeBuilder() {
    super(MetadataFormat.JAVA);
    this.messageTypeBuilder = new MessageMetadataTypeBuilder();
    this.variables = new ObjectTypeBuilder(MetadataFormat.JAVA);
  }

  public MessageMetadataTypeBuilder message() {
    return messageTypeBuilder;
  }

  public MuleEventMetadataTypeBuilder message(MessageMetadataTypeBuilder messageTypeBuilder) {
    this.messageTypeBuilder = messageTypeBuilder;
    return this;
  }

  public MuleEventMetadataTypeBuilder message(MessageMetadataType messageMetadataType) {
    this.messageMetadataType = messageMetadataType;
    return this;
  }

  public BaseTypeBuilder addVariable(String name) {
    return addVariableField(name).value();
  }

  public MuleEventMetadataTypeBuilder addVariable(String name, MetadataType metadataType) {
    addVariableField(name).value(metadataType);
    return this;
  }

  private ObjectFieldTypeBuilder addVariableField(String name) {
    return variables.addField().required(true).key(name);
  }

  public static MuleEventMetadataTypeBuilder fromObjectType(ObjectType eventDefinition) {
    MuleEventMetadataTypeBuilder builder = new MuleEventMetadataTypeBuilder();
    Collection<ObjectFieldType> fields = eventDefinition.getFields();
    for (ObjectFieldType field : fields) {
      if (field.getKey().isName()) {
        String fieldName = field.getKey().getName().getLocalPart();
        if (fieldName.equals(DefaultMuleEventMetadataType.MESSAGE_FIELD_NAME)) {
          MetadataType messageType = field.getValue();
          if (messageType instanceof ObjectType) {
            ObjectType objectMessageType = (ObjectType) messageType;
            objectMessageType.getFieldByName(DefaultMessageMetadataType.PAYLOAD_FIELD_NAME)
                .ifPresent(objectFieldType -> builder.message().payload(objectFieldType.getValue()));
            objectMessageType.getFieldByName(DefaultMessageMetadataType.ATTRIBUTES_FIELD_NAME)
                .ifPresent(objectFieldType -> builder.message().attributes(objectFieldType.getValue()));
          }
        } else if (fieldName.equals(DefaultMuleEventMetadataType.VARIABLES_FIELD_NAME)) {
          MetadataType variables = field.getValue();
          if (variables instanceof ObjectType) {
            Collection<ObjectFieldType> allVariables = ((ObjectType) variables).getFields();
            for (ObjectFieldType variable : allVariables) {
              builder.addVariable(variable.getKey().getName().getLocalPart(), variable.getValue());
            }
          }
        }
      }
    }
    return builder;
  }

  @Override
  public MuleEventMetadataType build() {
    return new DefaultMuleEventMetadataType(messageMetadataType != null ? messageMetadataType : messageTypeBuilder.build(),
                                            variables.build(), annotations);
  }

  public MuleEventMetadataTypeBuilder with(TypeAnnotation extension) {
    this.addExtension(extension);
    return this;
  }
}

==> mule-message-metadata-model-1.1.2-sources.jar: org/mule/metadata/message/api/MuleEventMetadataTypeBuilder.java <==
/*
 * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 * The software in this package is published under the terms of the CPAL v1.0
 * license, a copy of which has been included with this distribution in the
 * LICENSE.txt file.
 */
package org.mule.metadata.message.api;


import org.mule.metadata.api.annotation.TypeAnnotation;
import org.mule.metadata.api.builder.AbstractBuilder;
import org.mule.metadata.api.builder.BaseTypeBuilder;
import org.mule.metadata.api.builder.ObjectFieldTypeBuilder;
import org.mule.metadata.api.builder.ObjectTypeBuilder;
import org.mule.metadata.api.builder.WithAnnotation;
import org.mule.metadata.api.model.MetadataFormat;
import org.mule.metadata.api.model.MetadataType;
import org.mule.metadata.api.model.ObjectFieldType;
import org.mule.metadata.api.model.ObjectType;

import java.util.Collection;

/**
 * Builder for the {@link MuleEventMetadataType}
 */
public class MuleEventMetadataTypeBuilder extends AbstractBuilder<MuleEventMetadataType>
    implements WithAnnotation<MuleEventMetadataTypeBuilder> {

  private MessageMetadataType messageMetadataType;
  private MessageMetadataTypeBuilder messageTypeBuilder;
  private ObjectTypeBuilder variables;
  private MetadataType errorType;

  public MuleEventMetadataTypeBuilder() {
    super(MetadataFormat.JAVA);
    this.messageTypeBuilder = new MessageMetadataTypeBuilder();
    this.variables = new ObjectTypeBuilder(MetadataFormat.JAVA);
    this.errorType = null;
  }

  public MessageMetadataTypeBuilder message() {
    return messageTypeBuilder;
  }

  public MuleEventMetadataTypeBuilder message(MessageMetadataTypeBuilder messageTypeBuilder) {
    this.messageTypeBuilder = messageTypeBuilder;
    return this;
  }

  public MuleEventMetadataTypeBuilder message(MessageMetadataType messageMetadataType) {
    this.messageMetadataType = messageMetadataType;
    return this;
  }

  public MuleEventMetadataTypeBuilder error(MetadataType errorType) {
    this.errorType = errorType;
    return this;
  }

  public BaseTypeBuilder addVariable(String name) {
    return addVariableField(name).value();
  }

  public MuleEventMetadataTypeBuilder addVariable(String name, MetadataType metadataType) {
    addVariableField(name).value(metadataType);
    return this;
  }

  public ObjectFieldTypeBuilder addVariableField(String name) {
    return variables.addField().required(true).key(name);
  }

  public static MuleEventMetadataTypeBuilder fromObjectType(ObjectType eventDefinition) {
    MuleEventMetadataTypeBuilder builder = new MuleEventMetadataTypeBuilder();
    Collection<ObjectFieldType> fields = eventDefinition.getFields();
    for (ObjectFieldType field : fields) {
      if (field.getKey().isName()) {
        String fieldName = field.getKey().getName().getLocalPart();
        if (fieldName.equals(DefaultMuleEventMetadataType.MESSAGE_FIELD_NAME)) {
          MetadataType messageType = field.getValue();
          if (messageType instanceof ObjectType) {
            builder.message(MessageMetadataTypeBuilder.fromObjectType((ObjectType) messageType));
          }
        } else if (fieldName.equals(DefaultMuleEventMetadataType.ERROR_FIELD_NAME)) {
          MetadataType errorType = field.getValue();
          builder.error(errorType);
        } else if (fieldName.equals(DefaultMuleEventMetadataType.VARIABLES_FIELD_NAME)) {
          MetadataType variables = field.getValue();
          if (variables instanceof ObjectType) {
            Collection<ObjectFieldType> allVariables = ((ObjectType) variables).getFields();
            for (ObjectFieldType variable : allVariables) {
              final ObjectFieldTypeBuilder objectFieldTypeBuilder =
                  builder.addVariableField(variable.getKey().getName().getLocalPart());
              objectFieldTypeBuilder.value(variable.getValue());
              variable.getAnnotations().forEach(objectFieldTypeBuilder::with);
            }
          }
        }
      }
    }
    return builder;
  }

  @Override
  public MuleEventMetadataType build() {
    return new DefaultMuleEventMetadataType(messageMetadataType != null ? messageMetadataType : messageTypeBuilder.build(),
                                            errorType,
                                            variables.build(), annotations);
  }

  public MuleEventMetadataTypeBuilder with(TypeAnnotation extension) {
    this.addExtension(extension);
    return this;
  }
}
